@@ -79,7 +79,7 @@ class ElfinderVolumeStorage(ElfinderVolumeDriver):
                 #do not accept the storage if listdir or url are not implemented
                 try:
                     opts['storage'].listdir(self._root)
-                    rooturl = opts['storage'].url(self._root)
+                    opts['storage'].url(self._root)
                 except NotImplementedError:
                     raise Exception('Storage %s should implement both the listdir() and url() methods to be valid for use with yawd-elfinder.' % self._options['storage'].__class__)
 
@@ -525,7 +525,7 @@ class ElfinderVolumeStorage(ElfinderVolumeDriver):
         if os.path.isdir(path):
             return 'directory'
 
-        mime = magic.Magic(mime=True).from_file(path)
+        mime = magic.Magic(mime=True).from_file(path.encode('utf-8')) #unicode filename support
         int_mime = None
 
         if not mime or mime in ['inode/x-empty', 'application/empty']:
